Crate ark_ed_on_cp6_782

Crate ark_ed_on_cp6_782 

This library implements a twisted Edwards curve whose base field is the scalar field of the curve CP6. This allows defining cryptographic primitives that use elliptic curves over the scalar field of the latter curve. This curve was generated as part of the paper [BCGMMW20, “Zexe”].

Curve information:

  • Base field: q = 258664426012969094010652733694893533536393512754914660539884262666720468348340822774968888139573360124440321458177
  • Scalar field: r = 32333053251621136751331591711861691692049189094364332567435817881934511297123972799646723302813083835942624121493
  • Valuation(q - 1, 2) = 46
  • Valuation(r - 1, 2) = 2
  • Curve equation: ax^2 + y^2 =1 + dx^2y^2, where
    • a = -1
    • d = 79743

Modules

fq
fr

Structs

EdwardsConfig
FqConfig
FrConfig

Constants

GENERATOR_X
GENERATOR_X = 174701772324485506941690903512423551998294352968833659960042362742684869862495746426366187462669992073196420267127
GENERATOR_Y
GENERATOR_Y = 208487200052258845495340374451540775445408439654930191324011635560142523886549663106522691296420655144190624954833

Type Aliases

EdwardsAffine
EdwardsProjective
Fq
Fr